@@ -69,7 +69,7 @@
 #ifdef WITH_TLS
 #  ifdef WITH_COA
 #    ifndef WITHOUT_COA_TUNNEL
-#      define WITH_COA_TUNNEL (1)
+//#      define WITH_COA_TUNNEL (1)
 #    endif
 #  endif
 #endif
@@ -79,6 +79,22 @@
 #    error Reverse CoA requests requires TLS
 #  endif
 #endif
+
+#ifdef WITH_RADIUSV11_ONLY
+#  define WITH_RADIUSV11
+#else
+#  ifndef WITHOUT_RADIUSV11
+#    ifdef WITH_TLS
+//#      define WITH_RADIUSV11
+#    endif
+#  endif
+#endif
+
+#ifdef WITH_RADIUSV11
+#  ifndef WITH_TLS
+#    error RADIUSv11 requires TLS
+#  endif
+#endif
 #define WITH_ASCEND_BINARY 1
 #define WITH_DHCP 1
 #define WITH_NDEBUG 1
@@ -86,5 +102,5 @@
 #define WITH_THREADS 1
 #define WITH_UDPFROMTO /**/
 #define WITH_VMPS 1
-#define RADIUSD_VERSION 030201
-#define RADIUSD_VERSION_STRING "3.2.1"
+#define RADIUSD_VERSION 030207
+#define RADIUSD_VERSION_STRING "3.2.7"
